STAGE: DISCUSSION DOCUMENT

OBJECTIVES:

- Define lineal admixture time.

- Invite discussion and feedback, especially regarding questions at the end of this document.

- Facilitate the discovery of mathematical tools, using this definition, that are useful to downstream empirical research.

SIGNIFICANCE: This definition is interpretable within empirical research without assuming particular mathematical models of demographic or genetic processes.

DOWNSTREAM RESEARCH: The estimation of the timing and extent of interbreeding between previously separated populations.